<?php
/**
 * Plugin plxMyAkismet
 *
 * @package	PLX
 * @author	Stephane F, Jean-Pierre Pourrez "bazooka07"
 *
 * https://akismet.com/development/api/#comment-check
 **/

/*
 * A partir de PluXml 5.5 la variable $selector1 a été renommé en $selector.
 * */
class plxMyAkismet extends plxPlugin {

	const BEGIN_CODE = '<?php' . PHP_EOL;
	const END_CODE = PHP_EOL . '?>';

	/**
	 * Constructeur de la classe
	 *
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	null
	 * @author	Stephane F
	 **/
	public function __construct($default_lang) {

		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# droits pour accéder à la page config.php et admin.php du plugin
		$this->setConfigProfil(PROFIL_ADMIN);
		# $this->setAdminProfil(PROFIL_ADMIN);

		if(!empty(trim($this->getParam('api_key')))) {
			# ajout des hooks
			foreach(array(
				'plxMotorAddCommentaireXml',
				'AdminTopBottom',
				'AdminCommentsTop',
			) as $hook) {
				if($hook == 'plxMotorAddCommentaireXml' or basename($_SERVER['SCRIPT_NAME']) == 'comments.php') {
					$this->addHook($hook, $hook);
				}
			}
		}
	}

	/**
	 * Méthode qui change le nom du fichier de commentaire si spam
	 *
	 * @return	stdio
	 * @author	Stéphane F.
	 **/
	public function plxMotorAddCommentaireXml() {

		echo self::BEGIN_CODE;
?>
include PLX_PLUGINS . '<?= __CLASS__ ?>/Akismet.class.php';

$akismet = new Akismet($this->racine, '<?= $this->getParam('api_key') ?>');
$akismet->setCommentAuthor($content['author']);
$akismet->setCommentAuthorEmail($content['mail']);
$akismet->setCommentAuthorURL($content['site']);
$akismet->setCommentContent($content['content']);

if($akismet->isCommentSpam()) {
	# change filename if spam
	$content["filename"] = preg_replace('@^_?@', '~', $content["filename"]);
}
<?php
		echo self::END_CODE;
	}

	public function AdminTopBottom() {
		echo self::BEGIN_CODE;
?>
if(
	(!empty($_GET['sel']) AND $_GET['sel'] == 'spam') OR
	(isset($_SESSION['selCom']) AND $_SESSION['selCom'] == 'spam')
) {
	$comSel = 'spam';
	$comSelMotif = '@^~\d{4}\.(.*)\.xml$@';
	$_SESSION['selCom'] = 'spam';
	$nbComPagination = $plxAdmin->nbComments($comSelMotif);
	$h2 = '<h2><?= $this->getLang('SPAM_LIST') ?></h2>';
} else {
	$comSel = !empty($_SESSION['selCom']) ? $_SESSION['selCom'] : 'all';
}
<?php
		echo self::END_CODE;
	}

	public function AdminCommentsTop() {
		echo self::BEGIN_CODE;
?>
$breadcrumbs[] = '<li><a' . ($_SESSION['selCom'] == 'spam' ? ' class="selected"' : '') . ' href="comments.php?sel=spam&page=1">Spam</a>&nbsp;(' . $plxAdmin->nbComments('@~\d{4}\.(.*)\.xml$@') . ')</li>';

if($comSel == 'spam') {
	if(defined('PLX_VERSION') and version_compare(PLX_VERSION, '5.5', '>=')) {
		$selector = selector('all', 'id_selection');
	} else {
		$selector1 = selector('all', 'id_selection1');
	}
}
<?php
		echo self::END_CODE;
	}
}
